@@ -1,5 +1,6 @@
 """Manage a web host."""
 
+import pathlib
 import shutil
 
 import feedparser
@@ -244,7 +245,6 @@ class Applications:
             install_app,
             app,
             str(tx.gaea.home_dir),
-            str(tx.gaea.working_dir),
             tx.gaea.get_config()["tokens"]["github"],
         )
         return "installing and restarting.."
@@ -269,13 +269,18 @@ class Applications:
         # XXX       app_url, _cwd=tx.gaea.home_dir)
 
 
-def install_app(app, home_dir, working_dir, github_token):
+def install_app(app, home_dir, github_token):
     if app.startswith("https://"):  # Git repo
         pass  # TODO
     elif "/" in app:  # GitHub project
-        working_dir = working_dir
-        sh.git("clone", f"https://github.com/{app}.git", _cwd=working_dir)
-        sh.poetry("install", _cwd=working_dir + f"/{app}")
+        print(home_dir)
+        working_dir = pathlib.Path(home_dir) / "working"
+        user, _, repo = app.partition("/")
+        sh.mkdir(working_dir / user, "-p")
+        sh.git("clone", f"https://github.com/{app}.git", _cwd=working_dir / user)
+        sh.Command(f"{home_dir}/.local/bin/poetry")(
+            "install", _cwd=working_dir / user / repo
+        )
 
         # XXX gh_prefix = f"https://api.github.com/repos/{app}/releases"
         # XXX gh_token_header = f"token {github_token}"
